@@ -88,8 +88,6 @@ private:
     bool m_initDone;
     int m_buttonMask;
     QMap<unsigned int, bool> m_mods;
-    int m_x, m_y, m_w, m_h;
-    bool m_repaint;
     bool m_quitFlag;
     bool m_firstPasswordTry;
     bool m_dontSendClipboard;
